# TOML Conf

_The tiny TOML configuration tool._



Write less code and spend your time on what matters most, not the boring configuration:

* Plug it in and go; works out of the box.
* Exception handling best practices.
* Simple and easy-to-read; PEP8 compliant.
* Tested POSIX support.
* Cross-platform per-user config file locations.



Built on TOML Kit:

* A fast, 0.5.0-compliant TOML parser.
* Preserves the layout, style, and the order of configuration data.



#### Quick Start

##### Installation

```
pip install tomlconf
```

See the [Documentation](https://www.notion.so/rmtf/TOML-Conf-ac39b49704624c7aa46d32374f38bb3e) for more information.